@@ -428,20 +428,20 @@ class AssetsAPI(APIClient):
                 >>> my_update = AssetUpdate(id=1).description.set("New description").metadata.add({"key": "value"})
                 >>> res = c.assets.update(my_update)
 
-            Attach a label to an asset::
+            Attach labels to an asset::
 
                 >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
                 >>> c = CogniteClient()
-                >>> my_update = AssetUpdate(id=1).labels.add(["PUMP"])
+                >>> my_update = AssetUpdate(id=1).labels.add(["PUMP", "VERIFIED"])
                 >>> res = c.assets.update(my_update)
 
-            Detach a label from an asset::
+            Detach a single label from an asset::
 
                 >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
                 >>> c = CogniteClient()
-                >>> my_update = AssetUpdate(id=1).labels.remove(["PUMP"])
+                >>> my_update = AssetUpdate(id=1).labels.remove("PUMP")
                 >>> res = c.assets.update(my_update)
         """
         return self._update_multiple(items=item)
@@ -492,6 +492,13 @@ class AssetsAPI(APIClient):
                 >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>> res = c.assets.search(name="xyz",filter={"parent_ids": [123,456],"source": "some source"})
+
+            Search for an asset with an attached label:
+
+                >>> from cognite.client import CogniteClient
+                >>> c = CogniteClient()
+                >>> my_label_filter = LabelFilter(contains_all=["PUMP"])
+                >>> res = c.assets.search(name="xyz",filter=AssetFilter(labels=my_label_filter))
         """
         return self._search(
             search={"name": name, "description": description, "query": query}, filter=filter, limit=limit
