@@ -6,7 +6,6 @@ from cognite.client.data_classes._base import *
 from cognite.client.data_classes.shared import TimestampRange
 
 
-# GenClass: GetSequenceDTO
 class Sequence(CogniteResource):
     """Information about the sequence stored in the database
 
@@ -50,8 +49,6 @@ class Sequence(CogniteResource):
         self.data_set_id = data_set_id
         self._cognite_client = cognite_client
 
-    # GenStop
-
     def rows(self, start: int, end: int) -> List[dict]:
         """Retrieves rows from this sequence.
 
@@ -80,7 +77,6 @@ class Sequence(CogniteResource):
         return [c.get("valueType") for c in self.columns]
 
 
-# GenClass: SequenceFilter
 class SequenceFilter(CogniteFilter):
     """No description.
 
@@ -131,10 +127,7 @@ class SequenceFilter(CogniteFilter):
                 instance.last_updated_time = TimestampRange(**instance.last_updated_time)
         return instance
 
-    # GenStop
 
-
-# GenUpdateClass: SequencesUpdate
 class SequenceUpdate(CogniteUpdate):
     """No description.
 
@@ -143,61 +136,62 @@ class SequenceUpdate(CogniteUpdate):
         external_id (str): The external ID provided by the client. Must be unique for the resource type.
     """
 
+    class _PrimitiveSequenceUpdate(CognitePrimitiveUpdate):
+        def set(self, value: Any) -> "SequenceUpdate":
+            return self._set(value)
+
+    class _ObjectSequenceUpdate(CogniteObjectUpdate):
+        def set(self, value: Dict) -> "SequenceUpdate":
+            return self._set(value)
+
+        def add(self, value: Dict) -> "SequenceUpdate":
+            return self._add(value)
+
+        def remove(self, value: List) -> "SequenceUpdate":
+            return self._remove(value)
+
+    class _ListSequenceUpdate(CogniteListUpdate):
+        def set(self, value: List) -> "SequenceUpdate":
+            return self._set(value)
+
+        def add(self, value: List) -> "SequenceUpdate":
+            return self._add(value)
+
+        def remove(self, value: List) -> "SequenceUpdate":
+            return self._remove(value)
+
+    class _LabelSequenceUpdate(CogniteLabelUpdate):
+        def add(self, value: List) -> "SequenceUpdate":
+            return self._add(value)
+
+        def remove(self, value: List) -> "SequenceUpdate":
+            return self._remove(value)
+
     @property
     def name(self):
-        return _PrimitiveSequenceUpdate(self, "name")
+        return SequenceUpdate._PrimitiveSequenceUpdate(self, "name")
 
     @property
     def description(self):
-        return _PrimitiveSequenceUpdate(self, "description")
+        return SequenceUpdate._PrimitiveSequenceUpdate(self, "description")
 
     @property
     def asset_id(self):
-        return _PrimitiveSequenceUpdate(self, "assetId")
+        return SequenceUpdate._PrimitiveSequenceUpdate(self, "assetId")
 
     @property
     def external_id(self):
-        return _PrimitiveSequenceUpdate(self, "externalId")
+        return SequenceUpdate._PrimitiveSequenceUpdate(self, "externalId")
 
     @property
     def metadata(self):
-        return _ObjectSequenceUpdate(self, "metadata")
+        return SequenceUpdate._ObjectSequenceUpdate(self, "metadata")
 
     @property
     def data_set_id(self):
-        return _PrimitiveSequenceUpdate(self, "dataSetId")
+        return SequenceUpdate._PrimitiveSequenceUpdate(self, "dataSetId")
 
 
-class _PrimitiveSequenceUpdate(CognitePrimitiveUpdate):
-    def set(self, value: Any) -> SequenceUpdate:
-        return self._set(value)
-
-
-class _ObjectSequenceUpdate(CogniteObjectUpdate):
-    def set(self, value: Dict) -> SequenceUpdate:
-        return self._set(value)
-
-    def add(self, value: Dict) -> SequenceUpdate:
-        return self._add(value)
-
-    def remove(self, value: List) -> SequenceUpdate:
-        return self._remove(value)
-
-
-class _ListSequenceUpdate(CogniteListUpdate):
-    def set(self, value: List) -> SequenceUpdate:
-        return self._set(value)
-
-    def add(self, value: List) -> SequenceUpdate:
-        return self._add(value)
-
-    def remove(self, value: List) -> SequenceUpdate:
-        return self._remove(value)
-
-    # GenStop
-
-
-# GenPropertyClass: SequenceAggregateResponse.items
 class SequenceAggregate(dict):
     """No description.
 
@@ -211,8 +205,6 @@ class SequenceAggregate(dict):
 
     count = CognitePropertyClassUtil.declare_property("count")
 
-    # GenStop
-
 
 class SequenceList(CogniteResourceList):
     _RESOURCE = Sequence
